@@ -1,7 +1,7 @@
 // qsynthPresetForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -40,7 +40,7 @@ class qsynthPresetForm : public QDialog
 public:
 
 	// Constructor.
-	qsynthPresetForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qsynthPresetForm(QWidget *pParent = nullptr);
 	// Destructor.
 	~qsynthPresetForm();
 
