@@ -9,167 +9,216 @@
         <translation>(výchozí)</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="200"/>
+        <location filename="../qsynthOptions.cpp" line="224"/>
         <source>Usage: %1 [options] [soundfonts] [midifiles]</source>
-        <translation>Použití: %1 [volby] [zvuková písma] [soubory MIDI]</translation>
+        <translation>Použití: %1 [volby] [zvukové banky] [soubory MIDI]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="203"/>
+        <location filename="../qsynthOptions.cpp" line="227"/>
         <source>Options</source>
         <translation>Volby</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="205"/>
+        <location filename="../qsynthOptions.cpp" line="229"/>
+        <location filename="../qsynthOptions.cpp" line="285"/>
         <source>Don&apos;t create a midi driver to read MIDI input events [default = yes]</source>
         <translation>Nevytvářet žádný ovladač MIDI kvůli čtení vstupních událostí MIDI [výchozí = yes]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="207"/>
+        <location filename="../qsynthOptions.cpp" line="231"/>
+        <location filename="../qsynthOptions.cpp" line="287"/>
         <source>The name of the midi driver to use [oss,alsa,alsa_seq,...]</source>
         <translation>Název používaného ovladače MIDI [oss, alsa, alsa_seq,...]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="209"/>
+        <location filename="../qsynthOptions.cpp" line="233"/>
+        <location filename="../qsynthOptions.cpp" line="289"/>
         <source>The number of midi channels [default = 16]</source>
         <translation>Počet kanálů MIDIe [výchozí = 16]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="211"/>
+        <location filename="../qsynthOptions.cpp" line="235"/>
+        <location filename="../qsynthOptions.cpp" line="291"/>
         <source>The audio driver [alsa,jack,oss,dsound,...]</source>
         <translation>Zvukový ovladač [alsa, jack, oss, dsound,...]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="213"/>
+        <location filename="../qsynthOptions.cpp" line="237"/>
+        <location filename="../qsynthOptions.cpp" line="293"/>
         <source>Attempt to connect the jack outputs to the physical ports</source>
-        <translation>Pokusit o spojení výstupů JACK s fyzickými přípojkami</translation>
+        <translation>Pokusit se o spojení výstupů JACK s fyzickými přípojkami</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="215"/>
+        <location filename="../qsynthOptions.cpp" line="239"/>
+        <location filename="../qsynthOptions.cpp" line="295"/>
         <source>The number of stereo audio channels [default = 1]</source>
         <translation>Počet stereo zvukových kanálů [výchozí = 1]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="217"/>
+        <location filename="../qsynthOptions.cpp" line="241"/>
+        <location filename="../qsynthOptions.cpp" line="297"/>
         <source>The number of audio groups [default = 1]</source>
         <translation>Počet zvukových skupin [výchozí = 1]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="219"/>
+        <location filename="../qsynthOptions.cpp" line="243"/>
+        <location filename="../qsynthOptions.cpp" line="299"/>
         <source>Size of each audio buffer</source>
         <translation>Velikost zvukové vyrovnávací paměti</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="221"/>
+        <location filename="../qsynthOptions.cpp" line="245"/>
+        <location filename="../qsynthOptions.cpp" line="301"/>
         <source>Number of audio buffers</source>
         <translation>Počet zvukových vyrovnávacích pamětí</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="223"/>
+        <location filename="../qsynthOptions.cpp" line="247"/>
+        <location filename="../qsynthOptions.cpp" line="303"/>
         <source>Set the sample rate</source>
         <translation>Nastavit vzorkovací kmitočet</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="225"/>
+        <location filename="../qsynthOptions.cpp" line="249"/>
+        <location filename="../qsynthOptions.cpp" line="305"/>
         <source>Turn the reverb on or off [1|0|yes|no|on|off, default = on]</source>
         <translation>Zapnout nebo vypnout dozvuk [[1|0|yes|no|on|off, výchozí = on]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="227"/>
+        <location filename="../qsynthOptions.cpp" line="251"/>
+        <location filename="../qsynthOptions.cpp" line="307"/>
         <source>Turn the chorus on or off [1|0|yes|no|on|off, default = on]</source>
-        <translation>Zapnout nebo vypnout sbor [[1|0|yes|no|on|off, Voreinstellung = on]</translation>
+        <translation>Zapnout nebo vypnout sbor [[1|0|yes|no|on|off, výchozí = on]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="229"/>
-        <source>Set the master gain [0 &lt; gain &lt; 10, default = 0.2]</source>
-        <translation>Nastavit výstupní zesílení [0 &lt; zesílení &lt; 10, výchozí = 0.2]</translation>
+        <location filename="../qsynthOptions.cpp" line="253"/>
+        <location filename="../qsynthOptions.cpp" line="309"/>
+        <source>Set the master gain [0 &lt; gain &lt; 2, default = 1]</source>
+        <translation>Nastavit výstupní zesílení [0 &lt; zesílení &lt; 2, výchozí = 1]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="231"/>
+        <location filename="../qsynthOptions.cpp" line="255"/>
+        <location filename="../qsynthOptions.cpp" line="311"/>
         <source>Define a setting name=value</source>
         <translation>Stanovit nastavení název=hodnota</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="233"/>
+        <location filename="../qsynthOptions.cpp" line="257"/>
+        <location filename="../qsynthOptions.cpp" line="313"/>
         <source>Create and start server [default = no]</source>
         <translation>Vytvořit a spustit server [výchozí = ne]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="235"/>
+        <location filename="../qsynthOptions.cpp" line="259"/>
+        <location filename="../qsynthOptions.cpp" line="315"/>
         <source>Don&apos;t read commands from the shell [ignored]</source>
-        <translation>Nečíst příkazyze shellu [nebráno na vědomí]</translation>
+        <translation>Nečíst příkazy ze shellu [nebráno na vědomí]</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="237"/>
+        <location filename="../qsynthOptions.cpp" line="261"/>
+        <location filename="../qsynthOptions.cpp" line="317"/>
         <source>Dump midi router events</source>
         <translation>Zobrazit události směrovače MIDI</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="239"/>
+        <location filename="../qsynthOptions.cpp" line="263"/>
+        <location filename="../qsynthOptions.cpp" line="319"/>
         <source>Print out verbose messages about midi events</source>
-        <translation>Vytisknout podrobná hlášení o událostech MIDI</translation>
+        <translation>Zobrazit podrobná hlášení o událostech MIDI</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="241"/>
+        <location filename="../qsynthOptions.cpp" line="265"/>
         <source>Show help about command line options</source>
-        <translation>Ukázat nápovědu k argumentům příkazového řádku</translation>
+        <translation>Ukázat nápovědu k volbám příkazového řádku</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="243"/>
+        <location filename="../qsynthOptions.cpp" line="267"/>
         <source>Show version information</source>
-        <translation>Ukázat informaci o verzi</translation>
+        <translation>Ukázat informace o verzi</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="275"/>
+        <location filename="../qsynthOptions.cpp" line="323"/>
+        <source>SoundFont Files</source>
+        <translation>Soubory SoundFont</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="324"/>
+        <source>[soundfonts]</source>
+        <translation>[zvukové banky]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="326"/>
+        <source>MIDI Files</source>
+        <translation>Soubory MIDI</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="327"/>
+        <source>[midifiles]</source>
+        <translation>[soubory MIDI]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="337"/>
+        <location filename="../qsynthOptions.cpp" line="513"/>
         <source>Option -m requires an argument (midi-driver).</source>
         <translation>Volba -m potřebuje argument (midi-driver).</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="284"/>
+        <location filename="../qsynthOptions.cpp" line="347"/>
+        <location filename="../qsynthOptions.cpp" line="522"/>
         <source>Option -K requires an argument (midi-channels).</source>
         <translation>Volba -K potřebuje argument (midi-channels).</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="293"/>
+        <location filename="../qsynthOptions.cpp" line="356"/>
+        <location filename="../qsynthOptions.cpp" line="531"/>
         <source>Option -a requires an argument (audio-driver).</source>
         <translation>Volba -a potřebuje argument (audio-driver).</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="305"/>
+        <location filename="../qsynthOptions.cpp" line="370"/>
+        <location filename="../qsynthOptions.cpp" line="543"/>
         <source>Option -L requires an argument (audio-channels).</source>
         <translation>Volba -L potřebuje argument (audio-channels).</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="314"/>
+        <location filename="../qsynthOptions.cpp" line="380"/>
+        <location filename="../qsynthOptions.cpp" line="552"/>
         <source>Option -G requires an argument (audio-groups).</source>
         <translation>Volba -G potřebuje argument (audio-groups).</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="323"/>
+        <location filename="../qsynthOptions.cpp" line="390"/>
+        <location filename="../qsynthOptions.cpp" line="561"/>
         <source>Option -z requires an argument (audio-bufsize).</source>
         <translation>Volba -z potřebuje aArgument (audio-bufsize).</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="332"/>
+        <location filename="../qsynthOptions.cpp" line="400"/>
+        <location filename="../qsynthOptions.cpp" line="570"/>
         <source>Option -c requires an argument (audio-bufcount).</source>
         <translation>Volba -c potřebuje argument (audio-bufcount).</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="341"/>
+        <location filename="../qsynthOptions.cpp" line="410"/>
+        <location filename="../qsynthOptions.cpp" line="579"/>
         <source>Option -r requires an argument (sample-rate).</source>
         <translation>Volba -r potřebuje argument (sample-rate).</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="368"/>
+        <location filename="../qsynthOptions.cpp" line="438"/>
+        <location filename="../qsynthOptions.cpp" line="606"/>
         <source>Option -g requires an argument (gain).</source>
         <translation>Volba -g potřebuje argument (gain).</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="377"/>
+        <location filename="../qsynthOptions.cpp" line="447"/>
+        <location filename="../qsynthOptions.cpp" line="615"/>
         <source>Option -o requires an argument.</source>
         <translation>Volba -o potřebuje argument.</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="426"/>
+        <location filename="../qsynthOptions.cpp" line="482"/>
+        <location filename="../qsynthOptions.cpp" line="664"/>
         <source>Unknown option &apos;%1&apos;.</source>
         <translation>Neznámá volba: &apos;%1&apos;.</translation>
     </message>
@@ -322,7 +371,7 @@
     <message>
         <location filename="../qsynthChannelsForm.ui" line="201"/>
         <source>Soundfont</source>
-        <translation>Zvukové písmo</translation>
+        <translation>Zvuková banka</translation>
     </message>
     <message>
         <location filename="../qsynthChannelsForm.ui" line="36"/>
@@ -690,13 +739,13 @@ oblasti panelu.</translation>
     <message>
         <location filename="../qsynthMainForm.cpp" line="996"/>
         <source>Loading soundfont: &quot;%1&quot;</source>
-        <translation>Nahrává se zvukové písmo: &quot;%1&quot;</translation>
+        <translation>Nahrává se zvuková banka: &quot;%1&quot;</translation>
     </message>
     <message>
         <location filename="../qsynthMainForm.cpp" line="1007"/>
         <location filename="../qsynthMainForm.cpp" line="2034"/>
         <source>Failed to load the soundfont: &quot;%1&quot;.</source>
-        <translation>Nahrávání zvukového písma se nezdařilo: &quot;%1&quot;.</translation>
+        <translation>Nahrávání zvukové banky se nezdařilo: &quot;%1&quot;.</translation>
     </message>
     <message>
         <location filename="../qsynthMainForm.cpp" line="1034"/>
@@ -778,12 +827,12 @@ Bez něj nelze pokračovat.</translation>
     <message>
         <location filename="../qsynthMainForm.cpp" line="2028"/>
         <source>Loading soundfont: &quot;%1&quot; (bank offset %2)</source>
-        <translation>Nahrává se zvukové písmo: &quot;%1&quot; (poloha banky %2)</translation>
+        <translation>Nahrává se zvuková banka: &quot;%1&quot; (poloha banky %2)</translation>
     </message>
     <message>
         <location filename="../qsynthMainForm.cpp" line="2041"/>
         <source>Failed to set bank offset (%1) for soundfont: &quot;%2&quot;.</source>
-        <translation>Nastavení hodnoty polohy banky (%1) pro zvukové písmo: &quot;%2&quot; se nepodařilo.</translation>
+        <translation>Nastavení hodnoty polohy banky (%1) pro zvukovou banku: &quot;%2&quot; se nepodařilo.</translation>
     </message>
     <message>
         <location filename="../qsynthMainForm.cpp" line="2051"/>
@@ -908,12 +957,12 @@ Pokračuje se bez něj.</translation>
     <message>
         <location filename="../qsynthMainForm.cpp" line="2282"/>
         <source>Unloading soundfont: &quot;%1&quot; (SFID=%2)</source>
-        <translation>Vyjímá se zvukové písmo: &quot;%1&quot; (SFID=%2)</translation>
+        <translation>Ruší se nahrání zvukové banky: &quot;%1&quot; (SFID=%2)</translation>
     </message>
     <message>
         <location filename="../qsynthMainForm.cpp" line="2286"/>
         <source>Failed to unload the soundfont: &quot;%1&quot;.</source>
-        <translation>Vyjmutí zvukového písma: &quot;%1&quot; se nezdařilo.</translation>
+        <translation>Vyjmutí zvukové banky: &quot;%1&quot; se nezdařilo.</translation>
     </message>
     <message>
         <location filename="../qsynthMainForm.cpp" line="2293"/>
@@ -1155,39 +1204,39 @@ fluidsynthovéhoh zvukového modulu:</translation>
         <translation>Spustit se &amp;zmenšením do oznamovací oblasti panelu</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="298"/>
+        <location filename="../qsynthOptionsForm.cpp" line="315"/>
         <source>Information</source>
         <translation>Informace</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="299"/>
+        <location filename="../qsynthOptionsForm.cpp" line="316"/>
         <source>Some settings may be only effective
 next time you start this application.</source>
         <translation>Některá nastavení se projeví až tehdy,
 když příště spustíte tento program.</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="325"/>
+        <location filename="../qsynthOptionsForm.cpp" line="342"/>
         <source>Warning</source>
         <translation>Varování</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="326"/>
+        <location filename="../qsynthOptionsForm.cpp" line="343"/>
         <source>Some options have been changed.</source>
         <translation>Některá nastavení byla změněna.</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="327"/>
+        <location filename="../qsynthOptionsForm.cpp" line="344"/>
         <source>Do you want to apply the changes?</source>
         <translation>Chtěl byste použít změny?</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="456"/>
+        <location filename="../qsynthOptionsForm.cpp" line="501"/>
         <source>Messages Log</source>
         <translation>Zápis hlášení</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="458"/>
+        <location filename="../qsynthOptionsForm.cpp" line="503"/>
         <source>Log files</source>
         <translation>Soubory se zápisy</translation>
     </message>
@@ -1253,20 +1302,21 @@ když příště spustíte tento program.</translation>
         <translation>Výchozí</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="791"/>
+        <location filename="../qsynthOptionsForm.ui" line="819"/>
         <source>&amp;Base font size:</source>
         <translation>Základní velikost &amp;písma:</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="810"/>
+        <location filename="../qsynthOptionsForm.ui" line="838"/>
         <source>Base application font size (pt.)</source>
         <translation>Základní velikost písma v aplikaci (v bodech)</translation>
     </message>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="652"/>
         <location filename="../qsynthOptionsForm.ui" line="743"/>
-        <location filename="../qsynthOptionsForm.ui" line="817"/>
-        <location filename="../qsynthOptionsForm.cpp" line="42"/>
+        <location filename="../qsynthOptionsForm.ui" line="792"/>
+        <location filename="../qsynthOptionsForm.ui" line="845"/>
+        <location filename="../qsynthOptionsForm.cpp" line="44"/>
         <source>(default)</source>
         <translation>(výchozí)</translation>
     </message>
@@ -1313,27 +1363,32 @@ když příště spustíte tento program.</translation>
         <translation>Vlastní motiv stylu prvku</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="832"/>
+        <location filename="../qsynthOptionsForm.ui" line="775"/>
+        <source>Language</source>
+        <translation>Jazyk</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptionsForm.ui" line="860"/>
         <source>8</source>
         <translation>8</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="837"/>
+        <location filename="../qsynthOptionsForm.ui" line="865"/>
         <source>9</source>
         <translation>9</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="842"/>
+        <location filename="../qsynthOptionsForm.ui" line="870"/>
         <source>10</source>
         <translation>10</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="847"/>
+        <location filename="../qsynthOptionsForm.ui" line="875"/>
         <source>11</source>
         <translation>11</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="852"/>
+        <location filename="../qsynthOptionsForm.ui" line="880"/>
         <source>12</source>
         <translation>12</translation>
     </message>
@@ -1353,12 +1408,12 @@ když příště spustíte tento program.</translation>
         <translation>Odezva otočného regulátoru na po&amp;hyb myši:</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="822"/>
+        <location filename="../qsynthOptionsForm.ui" line="850"/>
         <source>6</source>
         <translation>6</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="827"/>
+        <location filename="../qsynthOptionsForm.ui" line="855"/>
         <source>7</source>
         <translation>7</translation>
     </message>
@@ -1593,7 +1648,7 @@ Chcete uložit změny?</translation>
     <message>
         <location filename="../qsynthPresetForm.ui" line="164"/>
         <source>Soundfont</source>
-        <translation>Zvukové písmo</translation>
+        <translation>Zvuková banka</translation>
     </message>
     <message>
         <location filename="../qsynthPresetForm.ui" line="173"/>
@@ -1663,7 +1718,7 @@ Chcete uložit změny?</translation>
     <message>
         <location filename="../qsynthSetupForm.ui" line="350"/>
         <source>Print out verbose messages about MIDI events</source>
-        <translation>Vytisknout podrobná hlášení o událostech MIDI</translation>
+        <translation>Zobrazit podrobná hlášení o událostech MIDI</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="353"/>
@@ -1974,7 +2029,7 @@ Chcete uložit změny?</translation>
     <message>
         <location filename="../qsynthSetupForm.ui" line="867"/>
         <source>&amp;Soundfonts</source>
-        <translation>&amp;Zvuková písma</translation>
+        <translation>&amp;Zvukové banky</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="882"/>
@@ -1995,12 +2050,12 @@ Chcete uložit změny?</translation>
     <message>
         <location filename="../qsynthSetupForm.ui" line="914"/>
         <source>Offset</source>
-        <translation>Poloha</translation>
+        <translation>Posun</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="927"/>
         <source>Open soundfont file for loading</source>
-        <translation>Otevřít soubor se zvukovým písmem pro nahrání</translation>
+        <translation>Otevřít soubor se zvukovou bankou pro nahrání</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="930"/>
@@ -2010,7 +2065,7 @@ Chcete uložit změny?</translation>
     <message>
         <location filename="../qsynthSetupForm.ui" line="940"/>
         <source>Edit selected soundfont bank offset</source>
-        <translation>Upravit hodnotu polohy vybrané banky se zvukovým písmem</translation>
+        <translation>Upravit hodnotu polohy vybrané banky se zvukovou bankou</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="943"/>
@@ -2020,7 +2075,7 @@ Chcete uložit změny?</translation>
     <message>
         <location filename="../qsynthSetupForm.ui" line="953"/>
         <source>Remove selected soundfont from stack</source>
-        <translation>Odstranit vybrané zvukové písmo ze zásobníku</translation>
+        <translation>Odstranit vybranou zvukovou banku ze zásobníku</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="956"/>
@@ -2030,7 +2085,7 @@ Chcete uložit změny?</translation>
     <message>
         <location filename="../qsynthSetupForm.ui" line="979"/>
         <source>Move up selected soundfont towards the top of stack</source>
-        <translation>Vybrané zvukové písmo přesunout v zásobníku nahoru</translation>
+        <translation>Vybranou zvukovou banku přesunout v zásobníku nahoru</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="982"/>
@@ -2040,7 +2095,7 @@ Chcete uložit změny?</translation>
     <message>
         <location filename="../qsynthSetupForm.ui" line="992"/>
         <source>Move down selected soundfont towards the bottom of stack</source>
-        <translation>Vybrané zvukové písmo přesunout v zásobníku dolů</translation>
+        <translation>Vybranou zvukovou banku přesunout v zásobníku dolů</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.ui" line="995"/>
@@ -2095,7 +2150,7 @@ Chcete uložit změny?</translation>
     </message>
     <message>
         <location filename="../qsynthSetupForm.cpp" line="637"/>
-        <location filename="../qsynthSetupForm.cpp" line="914"/>
+        <location filename="../qsynthSetupForm.cpp" line="921"/>
         <source>Warning</source>
         <translation>Varování</translation>
     </message>
@@ -2110,60 +2165,65 @@ Chcete uložit změny?</translation>
         <translation>Chtěl byste použít změny?</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="855"/>
+        <location filename="../qsynthSetupForm.cpp" line="857"/>
         <source>Open...</source>
         <translation>Otevřít...</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="860"/>
+        <location filename="../qsynthSetupForm.cpp" line="862"/>
         <source>Edit</source>
         <translation>Upravit</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="865"/>
+        <location filename="../qsynthSetupForm.cpp" line="867"/>
         <source>Remove</source>
         <translation>Odstranit</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="870"/>
+        <location filename="../qsynthSetupForm.cpp" line="872"/>
         <source>Move Up</source>
         <translation>Přesunout nahoru</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="874"/>
+        <location filename="../qsynthSetupForm.cpp" line="876"/>
         <source>Move Down</source>
         <translation>Přesunout dolů</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="899"/>
-        <location filename="../qsynthSetupForm.cpp" line="900"/>
+        <location filename="../qsynthSetupForm.cpp" line="901"/>
+        <location filename="../qsynthSetupForm.cpp" line="902"/>
         <source>Soundfont files</source>
-        <translation>Soubory se zvukovými písmy</translation>
+        <translation>Soubory se zvukovými bankami</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="915"/>
+        <location filename="../qsynthSetupForm.cpp" line="903"/>
+        <source>All files</source>
+        <translation>Všechny soubory</translation>
+    </message>
+    <message>
+        <location filename="../qsynthSetupForm.cpp" line="922"/>
         <source>Soundfont file already on list</source>
-        <translation>Soubor se zvukovým písmem je již součástí seznamu</translation>
+        <translation>Soubor se zvukovou bankou je již součástí seznamu</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="917"/>
+        <location filename="../qsynthSetupForm.cpp" line="924"/>
         <source>Add anyway?</source>
         <translation>Přesto přidat?</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="944"/>
+        <location filename="../qsynthSetupForm.cpp" line="951"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="945"/>
+        <location filename="../qsynthSetupForm.cpp" line="952"/>
         <source>Failed to add soundfont file</source>
-        <translation>Nepodařilo se přidat soubor se zvukovým písmem</translation>
+        <translation>Nepodařilo se přidat soubor se zvukovou bankou</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="947"/>
+        <location filename="../qsynthSetupForm.cpp" line="954"/>
         <source>Please, check for a valid soundfont file.</source>
-        <translation>Zvolte, prosím, platný soubor se zvukovým písmem.</translation>
+        <translation>Zvolte, prosím, platný soubor se zvukovou bankou.</translation>
     </message>
 </context>
 </TS>
