@@ -3,175 +3,224 @@
 <TS version="2.1" language="ru">
 <context>
     <name>QObject</name>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="203"/>
-        <source>Options</source>
-        <translation>Параметры</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="205"/>
-        <source>Don&apos;t create a midi driver to read MIDI input events [default = yes]</source>
-        <translation>Не создавать драйвер MIDI для чтения входящих событий MIDI [по умолчанию = yes]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="207"/>
-        <source>The name of the midi driver to use [oss,alsa,alsa_seq,...]</source>
-        <translation>Имя используемого драйвера MIDI [oss,alsa,alsa_seq,...]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="209"/>
-        <source>The number of midi channels [default = 16]</source>
-        <translation>Количество каналов MIDI [по умолчанию = 16]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="211"/>
-        <source>The audio driver [alsa,jack,oss,dsound,...]</source>
-        <translation>Звуковой драйвер [alsa,jack,oss,dsound,...]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="213"/>
-        <source>Attempt to connect the jack outputs to the physical ports</source>
-        <translation>Попытка связать выход JACK с физическими портами</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="215"/>
-        <source>The number of stereo audio channels [default = 1]</source>
-        <translation>Количество стереофонических звуковых каналов [по умолчанию = 1]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="217"/>
-        <source>The number of audio groups [default = 1]</source>
-        <translation>Количиство звуковых групп [по умолчанию = 1]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="219"/>
-        <source>Size of each audio buffer</source>
-        <translation>Размер каждого звукового буфера</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="221"/>
-        <source>Number of audio buffers</source>
-        <translation>Количество звуковых буферов</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="223"/>
-        <source>Set the sample rate</source>
-        <translation>Установить частоту семплирования</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="225"/>
-        <source>Turn the reverb on or off [1|0|yes|no|on|off, default = on]</source>
-        <translation>Включить/выключить реверберацию [1|0|yes|no|on|off, по умолчанию = on]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="227"/>
-        <source>Turn the chorus on or off [1|0|yes|no|on|off, default = on]</source>
-        <translation>Включить/выключить хорус [1|0|yes|no|on|off, по умолчанию = on]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="229"/>
-        <source>Set the master gain [0 &lt; gain &lt; 10, default = 0.2]</source>
-        <translation>Установить главное усиление [0 &lt; усиление &lt; 10, по умолчанию = 0.2]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="231"/>
-        <source>Define a setting name=value</source>
-        <translation>Определите имя=значение настройки</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="233"/>
-        <source>Create and start server [default = no]</source>
-        <translation>Создать и запустить сервер [по умолчанию = no]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="235"/>
-        <source>Don&apos;t read commands from the shell [ignored]</source>
-        <translation>Не считывать команды из оболочки [проигнорировано]</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="237"/>
-        <source>Dump midi router events</source>
-        <translation>Глушить события маршрутизатора MIDI</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="239"/>
-        <source>Print out verbose messages about midi events</source>
-        <translation>Показывать подробную информацию о сообщениях MIDI</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="241"/>
-        <source>Show help about command line options</source>
-        <translation>Показать справку о параметрах для командной строки</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="243"/>
-        <source>Show version information</source>
-        <translation>Показать информацию о версии</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="275"/>
-        <source>Option -m requires an argument (midi-driver).</source>
-        <translation>Ключ -m требует аргумента (midi-driver).</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="284"/>
-        <source>Option -K requires an argument (midi-channels).</source>
-        <translation>Ключ -K требует аргумента (midi-channels).</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="293"/>
-        <source>Option -a requires an argument (audio-driver).</source>
-        <translation>Ключ -a требует аргумента (audio-driver).</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="305"/>
-        <source>Option -L requires an argument (audio-channels).</source>
-        <translation>Ключ -L требует аргумента (audio-channels).</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="314"/>
-        <source>Option -G requires an argument (audio-groups).</source>
-        <translation>Ключ -G требует аргумента (audio-groups).</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="323"/>
-        <source>Option -z requires an argument (audio-bufsize).</source>
-        <translation>Ключ -a требует аргумента (audio-bufsize).</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="332"/>
-        <source>Option -c requires an argument (audio-bufcount).</source>
-        <translation>Ключ -c требует аргумента (audio-bufcount).</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="341"/>
-        <source>Option -r requires an argument (sample-rate).</source>
-        <translation>Ключ -r требует аргумента (sample-rate).</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="368"/>
-        <source>Option -g requires an argument (gain).</source>
-        <translation>Ключ -g требует аргумента (gain).</translation>
-    </message>
-    <message>
-        <location filename="../qsynthOptions.cpp" line="377"/>
-        <source>Option -o requires an argument.</source>
-        <translation>Ключ -o требует аргумента.</translation>
-    </message>
     <message>
         <location filename="../qsynthSetup.cpp" line="37"/>
         <source>(default)</source>
         <translation>(по умолчанию)</translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="200"/>
+        <location filename="../qsynthOptions.cpp" line="224"/>
         <source>Usage: %1 [options] [soundfonts] [midifiles]</source>
-        <translation>Использование: %1 [ключи] [файлы SF2] [файлы MIDI]</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qsynthOptions.cpp" line="426"/>
+        <location filename="../qsynthOptions.cpp" line="227"/>
+        <source>Options</source>
+        <translation type="unfinished">Параметры</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="229"/>
+        <location filename="../qsynthOptions.cpp" line="285"/>
+        <source>Don&apos;t create a midi driver to read MIDI input events [default = yes]</source>
+        <translation type="unfinished">Не создавать драйвер MIDI для чтения входящих событий MIDI [по умолчанию = yes]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="231"/>
+        <location filename="../qsynthOptions.cpp" line="287"/>
+        <source>The name of the midi driver to use [oss,alsa,alsa_seq,...]</source>
+        <translation type="unfinished">Имя используемого драйвера MIDI [oss,alsa,alsa_seq,...]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="233"/>
+        <location filename="../qsynthOptions.cpp" line="289"/>
+        <source>The number of midi channels [default = 16]</source>
+        <translation type="unfinished">Количество каналов MIDI [по умолчанию = 16]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="235"/>
+        <location filename="../qsynthOptions.cpp" line="291"/>
+        <source>The audio driver [alsa,jack,oss,dsound,...]</source>
+        <translation type="unfinished">Звуковой драйвер [alsa,jack,oss,dsound,...]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="237"/>
+        <location filename="../qsynthOptions.cpp" line="293"/>
+        <source>Attempt to connect the jack outputs to the physical ports</source>
+        <translation type="unfinished">Попытка связать выход JACK с физическими портами</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="239"/>
+        <location filename="../qsynthOptions.cpp" line="295"/>
+        <source>The number of stereo audio channels [default = 1]</source>
+        <translation type="unfinished">Количество стереофонических звуковых каналов [по умолчанию = 1]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="241"/>
+        <location filename="../qsynthOptions.cpp" line="297"/>
+        <source>The number of audio groups [default = 1]</source>
+        <translation type="unfinished">Количиство звуковых групп [по умолчанию = 1]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="243"/>
+        <location filename="../qsynthOptions.cpp" line="299"/>
+        <source>Size of each audio buffer</source>
+        <translation type="unfinished">Размер каждого звукового буфера</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="245"/>
+        <location filename="../qsynthOptions.cpp" line="301"/>
+        <source>Number of audio buffers</source>
+        <translation type="unfinished">Количество звуковых буферов</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="247"/>
+        <location filename="../qsynthOptions.cpp" line="303"/>
+        <source>Set the sample rate</source>
+        <translation type="unfinished">Установить частоту семплирования</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="249"/>
+        <location filename="../qsynthOptions.cpp" line="305"/>
+        <source>Turn the reverb on or off [1|0|yes|no|on|off, default = on]</source>
+        <translation type="unfinished">Включить/выключить реверберацию [1|0|yes|no|on|off, по умолчанию = on]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="251"/>
+        <location filename="../qsynthOptions.cpp" line="307"/>
+        <source>Turn the chorus on or off [1|0|yes|no|on|off, default = on]</source>
+        <translation type="unfinished">Включить/выключить хорус [1|0|yes|no|on|off, по умолчанию = on]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="253"/>
+        <location filename="../qsynthOptions.cpp" line="309"/>
+        <source>Set the master gain [0 &lt; gain &lt; 2, default = 1]</source>
+        <translation type="unfinished">Установить главное усиление [0 &lt; усиление &lt; 2, по умолчанию = 1]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="255"/>
+        <location filename="../qsynthOptions.cpp" line="311"/>
+        <source>Define a setting name=value</source>
+        <translation type="unfinished">Определите имя=значение настройки</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="257"/>
+        <location filename="../qsynthOptions.cpp" line="313"/>
+        <source>Create and start server [default = no]</source>
+        <translation type="unfinished">Создать и запустить сервер [по умолчанию = no]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="259"/>
+        <location filename="../qsynthOptions.cpp" line="315"/>
+        <source>Don&apos;t read commands from the shell [ignored]</source>
+        <translation type="unfinished">Не считывать команды из оболочки [проигнорировано]</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="261"/>
+        <location filename="../qsynthOptions.cpp" line="317"/>
+        <source>Dump midi router events</source>
+        <translation type="unfinished">Глушить события маршрутизатора MIDI</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="263"/>
+        <location filename="../qsynthOptions.cpp" line="319"/>
+        <source>Print out verbose messages about midi events</source>
+        <translation type="unfinished">Показывать подробную информацию о сообщениях MIDI</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="265"/>
+        <source>Show help about command line options</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="267"/>
+        <source>Show version information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="323"/>
+        <source>SoundFont Files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="324"/>
+        <source>[soundfonts]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="326"/>
+        <source>MIDI Files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="327"/>
+        <source>[midifiles]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="337"/>
+        <location filename="../qsynthOptions.cpp" line="513"/>
+        <source>Option -m requires an argument (midi-driver).</source>
+        <translation type="unfinished">Ключ -m требует аргумента (midi-driver).</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="347"/>
+        <location filename="../qsynthOptions.cpp" line="522"/>
+        <source>Option -K requires an argument (midi-channels).</source>
+        <translation type="unfinished">Ключ -K требует аргумента (midi-channels).</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="356"/>
+        <location filename="../qsynthOptions.cpp" line="531"/>
+        <source>Option -a requires an argument (audio-driver).</source>
+        <translation type="unfinished">Ключ -a требует аргумента (audio-driver).</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="370"/>
+        <location filename="../qsynthOptions.cpp" line="543"/>
+        <source>Option -L requires an argument (audio-channels).</source>
+        <translation type="unfinished">Ключ -L требует аргумента (audio-channels).</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="380"/>
+        <location filename="../qsynthOptions.cpp" line="552"/>
+        <source>Option -G requires an argument (audio-groups).</source>
+        <translation type="unfinished">Ключ -G требует аргумента (audio-groups).</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="390"/>
+        <location filename="../qsynthOptions.cpp" line="561"/>
+        <source>Option -z requires an argument (audio-bufsize).</source>
+        <translation type="unfinished">Ключ -a требует аргумента (audio-bufsize).</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="400"/>
+        <location filename="../qsynthOptions.cpp" line="570"/>
+        <source>Option -c requires an argument (audio-bufcount).</source>
+        <translation type="unfinished">Ключ -c требует аргумента (audio-bufcount).</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="410"/>
+        <location filename="../qsynthOptions.cpp" line="579"/>
+        <source>Option -r requires an argument (sample-rate).</source>
+        <translation type="unfinished">Ключ -r требует аргумента (sample-rate).</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="438"/>
+        <location filename="../qsynthOptions.cpp" line="606"/>
+        <source>Option -g requires an argument (gain).</source>
+        <translation type="unfinished">Ключ -g требует аргумента (gain).</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="447"/>
+        <location filename="../qsynthOptions.cpp" line="615"/>
+        <source>Option -o requires an argument.</source>
+        <translation type="unfinished">Ключ -o требует аргумента.</translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptions.cpp" line="482"/>
+        <location filename="../qsynthOptions.cpp" line="664"/>
         <source>Unknown option &apos;%1&apos;.</source>
-        <translation>неизвестный ключ &apos;%1&apos;.</translation>
+        <translation type="unfinished">неизвестный ключ &apos;%1&apos;.</translation>
     </message>
 </context>
 <context>
@@ -1090,38 +1139,38 @@ restarting all fluidsynth engines.</source>
 сообщений (stdout/stderr) для  окна сообщений</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="325"/>
+        <location filename="../qsynthOptionsForm.cpp" line="342"/>
         <source>Warning</source>
         <translation>Предупреждение</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="327"/>
+        <location filename="../qsynthOptionsForm.cpp" line="344"/>
         <source>Do you want to apply the changes?</source>
         <translation>Вы хотите учесть изменения?</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="326"/>
+        <location filename="../qsynthOptionsForm.cpp" line="343"/>
         <source>Some options have been changed.</source>
         <translation>Некоторые параметры были изменены.</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="298"/>
+        <location filename="../qsynthOptionsForm.cpp" line="315"/>
         <source>Information</source>
         <translation type="unfinished">Информация</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="299"/>
+        <location filename="../qsynthOptionsForm.cpp" line="316"/>
         <source>Some settings may be only effective
 next time you start this application.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="456"/>
+        <location filename="../qsynthOptionsForm.cpp" line="501"/>
         <source>Messages Log</source>
         <translation>Журнал сообщений</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.cpp" line="458"/>
+        <location filename="../qsynthOptionsForm.cpp" line="503"/>
         <source>Log files</source>
         <translation>Файлы журналов</translation>
     </message>
@@ -1315,20 +1364,21 @@ next time you start this application.</source>
         <translation>&amp;При старте скрывать окно в область уведомления</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="791"/>
+        <location filename="../qsynthOptionsForm.ui" line="819"/>
         <source>&amp;Base font size:</source>
         <translation>&amp;Кегль шрифта в GUI:</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="810"/>
+        <location filename="../qsynthOptionsForm.ui" line="838"/>
         <source>Base application font size (pt.)</source>
         <translation>Кегль шрифта в интерфейсе приложения (пункты)</translation>
     </message>
     <message>
         <location filename="../qsynthOptionsForm.ui" line="652"/>
         <location filename="../qsynthOptionsForm.ui" line="743"/>
-        <location filename="../qsynthOptionsForm.ui" line="817"/>
-        <location filename="../qsynthOptionsForm.cpp" line="42"/>
+        <location filename="../qsynthOptionsForm.ui" line="792"/>
+        <location filename="../qsynthOptionsForm.ui" line="845"/>
+        <location filename="../qsynthOptionsForm.cpp" line="44"/>
         <source>(default)</source>
         <translation>(по умолчанию)</translation>
     </message>
@@ -1338,37 +1388,42 @@ next time you start this application.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="822"/>
+        <location filename="../qsynthOptionsForm.ui" line="775"/>
+        <source>Language</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../qsynthOptionsForm.ui" line="850"/>
         <source>6</source>
         <translation>6</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="827"/>
+        <location filename="../qsynthOptionsForm.ui" line="855"/>
         <source>7</source>
         <translation>7</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="832"/>
+        <location filename="../qsynthOptionsForm.ui" line="860"/>
         <source>8</source>
         <translation>8</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="837"/>
+        <location filename="../qsynthOptionsForm.ui" line="865"/>
         <source>9</source>
         <translation>9</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="842"/>
+        <location filename="../qsynthOptionsForm.ui" line="870"/>
         <source>10</source>
         <translation>10</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="847"/>
+        <location filename="../qsynthOptionsForm.ui" line="875"/>
         <source>11</source>
         <translation>11</translation>
     </message>
     <message>
-        <location filename="../qsynthOptionsForm.ui" line="852"/>
+        <location filename="../qsynthOptionsForm.ui" line="880"/>
         <source>12</source>
         <translation>12</translation>
     </message>
@@ -1957,7 +2012,7 @@ Do you want to save the changes?</source>
     </message>
     <message>
         <location filename="../qsynthSetupForm.cpp" line="637"/>
-        <location filename="../qsynthSetupForm.cpp" line="914"/>
+        <location filename="../qsynthSetupForm.cpp" line="921"/>
         <source>Warning</source>
         <translation>Предупреждение</translation>
     </message>
@@ -1972,53 +2027,58 @@ Do you want to save the changes?</source>
         <translation>Вы хотите учесть изменения?</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="865"/>
+        <location filename="../qsynthSetupForm.cpp" line="867"/>
         <source>Remove</source>
         <translation>Удалить</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="870"/>
+        <location filename="../qsynthSetupForm.cpp" line="872"/>
         <source>Move Up</source>
         <translation>Переместить выше</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="874"/>
+        <location filename="../qsynthSetupForm.cpp" line="876"/>
         <source>Move Down</source>
         <translation>Переместить ниже</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="899"/>
-        <location filename="../qsynthSetupForm.cpp" line="900"/>
+        <location filename="../qsynthSetupForm.cpp" line="901"/>
+        <location filename="../qsynthSetupForm.cpp" line="902"/>
         <source>Soundfont files</source>
         <translation>Файлы SF2</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="944"/>
+        <location filename="../qsynthSetupForm.cpp" line="903"/>
+        <source>All files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../qsynthSetupForm.cpp" line="951"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="945"/>
+        <location filename="../qsynthSetupForm.cpp" line="952"/>
         <source>Failed to add soundfont file</source>
         <translation>Не удалось добавить файл SF2</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="947"/>
+        <location filename="../qsynthSetupForm.cpp" line="954"/>
         <source>Please, check for a valid soundfont file.</source>
         <translation>Проверьте целостность файла SF2</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="855"/>
+        <location filename="../qsynthSetupForm.cpp" line="857"/>
         <source>Open...</source>
         <translation>Открыть...</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="915"/>
+        <location filename="../qsynthSetupForm.cpp" line="922"/>
         <source>Soundfont file already on list</source>
         <translation>Этот файл SF2 уже есть в списке</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="917"/>
+        <location filename="../qsynthSetupForm.cpp" line="924"/>
         <source>Add anyway?</source>
         <translation>Всё равно добавить?</translation>
     </message>
@@ -2100,7 +2160,7 @@ Do you want to save the changes?</source>
         <translation>Параметры движка</translation>
     </message>
     <message>
-        <location filename="../qsynthSetupForm.cpp" line="860"/>
+        <location filename="../qsynthSetupForm.cpp" line="862"/>
         <source>Edit</source>
         <translation>Изменить</translation>
     </message>
